@@ -1,5 +1,5 @@
 from __future__ import absolute_import
 
 from lazyops.types.common import *
-from lazyops.types.models import BaseModel, BaseSettings, Field, validator
+from lazyops.types.models import BaseModel, BaseSettings, Schema, Field, validator
 from lazyops.types.classprops import lazyproperty, classproperty, cached_classproperty
\ No newline at end of file
